@@ -72,20 +72,30 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
         parent = RMainWindowQt.getMainWindow();
     }
 
-    var fileInfo = new QFileInfo(uiFile);
-    if (!fileInfo.exists() && !fileInfo.isAbsolute()) {
-        if (basePath.length>0) {
-            uiFile = basePath + "/" + uiFile;
-        }
+    var candidates;
+    if (!new QFileInfo(uiFile).isAbsolute()) {
+        candidates = [
+            uiFile,
+            basePath + "/" + uiFile,
+            ":" + uiFile,
+            ":" + basePath + "/" + uiFile
+        ];
+    }
+    else {
+        candidates = [
+            uiFile
+        ];
+    }
 
-        fileInfo = new QFileInfo(uiFile);
-        if (!fileInfo.exists()) {
-            uiFile = ":" + uiFile;
-            fileInfo = new QFileInfo(uiFile);
+    for (var i=0; i<candidates.length; i++) {
+        var candidate = candidates[i];
+        var fileInfo = new QFileInfo(candidate);
+        if (fileInfo.exists()) {
+            uiFile = candidate;
         }
     }
 
-    //fileInfo = new QFileInfo(uiFile);
+    var fileInfo = new QFileInfo(uiFile);
     if (!fileInfo.exists()) {
         qWarning("WidgetFactory: File %1 does not exist".arg(uiFile));
         return undefined;
@@ -131,7 +141,7 @@ WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     dialog.setWindowFlags(flags);
 
     // a global function might be defined to do additional
-    // initilization for all dialogs (e.g. for testing purposes):
+    // initialization for all dialogs (e.g. for testing purposes):
     if (typeof(initDialog)!=="undefined") {
         for (var i=0; i<initDialog.length; i++) {
             initDialog[i](dialog);
@@ -184,6 +194,31 @@ WidgetFactory.getKeyString = function(group, obj) {
     }
 };
 
+WidgetFactory.saveSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    RSettings.setValue(name + "/Width", widget.width);
+    RSettings.setValue(name + "/Height", widget.height);
+};
+
+WidgetFactory.restoreSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    var w = RSettings.getIntValue(name + "/Width", widget.width);
+    var h = RSettings.getIntValue(name + "/Height", widget.height);
+    widget.resize(w, h);
+};
+
 /**
  * Saves the current state of the given \c widget and all its child widgets.
  *
@@ -306,6 +341,9 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         else if (isOfType(c, QSpinBox) || isOfType(c, QDoubleSpinBox)) {
             value = c.value;
         }
+        else if (isOfType(c, QSlider)) {
+            value = c.value;
+        }
         else if (isOfType(c, QListWidget)) {
             var items = [];
             if (c.count != 0) {
@@ -547,7 +585,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 c.setPlainText(value);
             }
             continue;
-        }        
+        }
         if (isOfType(c, RMathLineEdit)) {
             WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
             c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
@@ -823,6 +861,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, QSlider)) {
+            WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+            c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+
+            if (isNull(c.defaultValue)) {
+                c.defaultValue = c.value;
+                if (signalReceiver!=undefined) {
+                    f = signalReceiver["slot" + c.objectName + "Changed"];
+                    if (isFunction(f)) {
+                        f.call(signalReceiver, c.value);
+                    }
+                }
+            }
+            if (!isNull(value)) {
+                c.value = value;
+            }
+            continue;
+        }
         if (isOfType(c, QListWidget)) {
             // the SaveContents property is set to false
             // if the list contents should not be saved to
@@ -1165,19 +1221,40 @@ WidgetFactory.initTextBrowser = function(textBrowser, linkHandler, slot) {
 //    }
 //};
 
-WidgetFactory.initLayerCombo = function(comboBox, doc) {
+WidgetFactory.initLayerCombo = function(comboBox, doc, clear) {
+    var i;
+
     if (isNull(doc)) {
         return;
     }
+    if (isNull(clear)) {
+        clear = true;
+    }
+
+    var existingLayerNames = [];
+    if (clear) {
+        comboBox.clear();
+    }
+    else {
+        for (i=0; i<comboBox.count; i++) {
+            var t = comboBox.itemText(i);
+            existingLayerNames.push(t);
+        }
+    }
 
-    comboBox.clear();
     comboBox.iconSize = new QSize(16, 10);
     var names = doc.getLayerNames();
     //names = RS.sortAlphanumerical(names);
     names.sort(Array.alphaNumericalSorter);
-    for (var i=0; i<names.length; i++) {
+    for (i=0; i<names.length; i++) {
         var name = names[i];
         var layer = doc.queryLayer(name);
+
+        if (existingLayerNames.containsIgnoreCase(layer.getName())) {
+            // don't overwrite existing layers:
+            continue;
+        }
+
         var icon = RColor.getIcon(layer.getColor(), new QSize(comboBox.iconSize.width(),10));
         comboBox.addItem(icon, layer.getName());
     }
